==> pygeofilter-0.0.0.tar.gz: pygeofilter-0.0.0/pygeofilter/values.py <==
# ------------------------------------------------------------------------------
#
# Project: pygeofilter <https://github.com/geopython/pygeofilter>
# Authors: Fabian Schindler <fabian.schindler@eox.at>
#
# ------------------------------------------------------------------------------
# Copyright (C) 2019 EOX IT Services GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies of this Software or works derived from this Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# ------------------------------------------------------------------------------


from dataclasses import dataclass
from datetime import date, time, datetime, timedelta

from pygeoif.geometry import as_shape


LITERALS = (list, str, float, int, bool, datetime, date, time, timedelta)


@dataclass
class Geometry:
    geometry: dict

    @property
    def __geo_interface__(self):
        return self.geometry

    def __eq__(self, o: object) -> bool:
        return (
            as_shape(self).__geo_interface__ == as_shape(o).__geo_interface__
        )


@dataclass
class Envelope:
    x1: float
    x2: float
    y1: float
    y2: float

==> pygeofilter-0.0.2.tar.gz: pygeofilter-0.0.2/pygeofilter/values.py <==
# ------------------------------------------------------------------------------
#
# Project: pygeofilter <https://github.com/geopython/pygeofilter>
# Authors: Fabian Schindler <fabian.schindler@eox.at>
#
# ------------------------------------------------------------------------------
# Copyright (C) 2019 EOX IT Services GmbH
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies of this Software or works derived from this Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# ------------------------------------------------------------------------------


from dataclasses import dataclass
from datetime import date, time, datetime, timedelta
from typing import Union, Optional

from pygeoif.geometry import as_shape


LITERALS = (list, str, float, int, bool, datetime, date, time, timedelta)


@dataclass
class Geometry:
    geometry: dict

    @property
    def __geo_interface__(self):
        return self.geometry

    def __eq__(self, o: object) -> bool:
        return (
            as_shape(self).__geo_interface__ == as_shape(o).__geo_interface__
        )


@dataclass
class Envelope:
    x1: float
    x2: float
    y1: float
    y2: float


@dataclass
class Interval:
    start: Optional[Union[date, datetime, timedelta]] = None
    end: Optional[Union[date, datetime, timedelta]] = None
